<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://oxyninja.com
 * @since      3.1.0
 *
 * @package    Oxy_Ninja
 * @subpackage Oxy_Ninja/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Oxy_Ninja
 * @subpackage Oxy_Ninja/public
 * @author     OxyNinja <rados@oxyninja.com>
 */
class Oxy_Ninja_Public {
	/**
	 * The ID of this plugin.
	 *
	 * @since    3.1.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    3.1.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.1.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    3.1.0
	 */
	public function enqueue_styles() {
		wp_register_style('splide', OXYNINJA_URI_PUBLIC . '/css/splide.min.css', [], '4.0.14', 'all');
		wp_register_style('glightbox', OXYNINJA_URI_PUBLIC . '/css/glightbox.min.css', [], '3.2.0', 'all');
		// TODO: Legacy - remove in future version
		wp_register_style('splide-css', OXYNINJA_URI_PUBLIC . '/css/splide.min.css', [], '4.0.14', 'all');

		wp_register_style('core-sss', OXYNINJA_URI_PUBLIC . '/css/core-sss.min.css', [], $this->version, 'all');
		wp_enqueue_style('core-sss');

		wp_register_style(
			'core-sizing',
			OXYNINJA_URI_PUBLIC . '/css/core-sizing.min.css',
			[],
			$this->version,
			'all'
		);
		wp_register_style(
			'core-spacing',
			OXYNINJA_URI_PUBLIC . '/css/core-spacing.min.css',
			[],
			$this->version,
			'all'
		);

		$oxyninja_storage = get_option('oxyninja_storage');

		if (isset($oxyninja_storage['sizing_stylesheet']) && isset($oxyninja_storage['spacing_stylesheet'])) {
			if (!$oxyninja_storage['sizing_stylesheet'] && !$oxyninja_storage['spacing_stylesheet']) {
				wp_dequeue_style('core-sss');
			} elseif ($oxyninja_storage['sizing_stylesheet'] && !$oxyninja_storage['spacing_stylesheet']) {
				wp_dequeue_style('core-sss');
				wp_enqueue_style('core-sizing');
			} elseif ($oxyninja_storage['spacing_stylesheet'] && !$oxyninja_storage['sizing_stylesheet']) {
				wp_dequeue_style('core-sss');
				wp_enqueue_style('core-spacing');
			}
		}
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    3.1.0
	 */
	public function enqueue_scripts() {
		wp_register_script('splide', OXYNINJA_URI_PUBLIC . '/js/splide/splide.min.js', [], '4.0.14', false);

		wp_register_script(
			'splide-autoscroll',
			OXYNINJA_URI_PUBLIC . '/js/splide/splide-extension-auto-scroll.min.js',
			['splide'],
			'0.5.2',
			false
		);

		wp_register_script(
			'glightbox',
			OXYNINJA_URI_PUBLIC . '/js/glightbox/glightbox.min.js',
			[],
			'3.2.0',
			false
		);

		wp_register_script('woocore-ajax', OXYNINJA_URI_PUBLIC . '/js/woocore-ajax.js', [], $this->version, true);
	}

	/**
	 * Product Thumbnails Flipper
	 *
	 * @since    3.1.0
	 * @version	 2.0.0
	 */
	public function oxyninja_second_product_thumbnail($atts) {
		$atts = array_change_key_case((array) $atts, CASE_LOWER);

		$is_atts = shortcode_atts(
			[
				'size' => 'shop_catalog',
			],
			$atts,
			'oxyninja-sec-image'
		);

		global $product;

		if (is_a($product, 'WC_Product')) {
			$attachment_ids = $product->get_gallery_image_ids();

			if ($attachment_ids) {
				$attachment_ids = array_values($attachment_ids);
				$secondary_image_id = $attachment_ids['0'];

				$secondary_image_alt = get_post_meta($secondary_image_id, '_wp_attachment_image_alt', true);

				echo wp_get_attachment_image($secondary_image_id, $is_atts['size'], '', [
					'class' => 'wc-secondary-image attachment-woocommerce_thumbnail',
					'alt' => $secondary_image_alt,
				]);
			}
		}
	}

	/**
	 * WC New Badge - Legacy
	 *
	 * @since    3.1.0
	 */
	public function oxyninja_new_badge() {
		global $product;
		if (is_a($product, 'WC_Product')) {
			$newness_days = 30;
			$created = strtotime($product->get_date_created());
			if (time() - 60 * 60 * 24 * $newness_days < $created) {
				echo '<span class="wc-new-badge">' . esc_html__('New!', 'oxy-ninja') . '</span>';
			}
		}
	}

	/**
	 * WC Sale Badge SplideJS
	 *
	 * @since    3.4.1
	 */
	public function oxyninja_out_of_stock_badge() {
		global $product;
		if (is_a($product, 'WC_Product')) {
			if (!$product->is_in_stock()) {
				echo '<span class="wc-oos-badge">' . esc_html__('Out of Stock', 'oxy-ninja') . '</span>';
			}
		}
	}

	/**
	 * WC New Badge SplideJS
	 *
	 * @since    3.2.0
	 */
	static function oxyninja_new_badge_splide() {
		global $product;
		if (is_a($product, 'WC_Product')) {
			$newness_days = 30;
			$created = strtotime($product->get_date_created());
			if (time() - 60 * 60 * 24 * $newness_days < $created) {
				echo '<span class="on-new">' . esc_html__('New!', 'oxy-ninja') . '</span>';
			}
		}
	}

	/**
	 * WC Sale Badge SplideJS
	 *
	 * @since    3.2.0
	 */
	static function oxyninja_sale_badge_splide() {
		global $product;
		if ($product->is_on_sale()) {
			echo '<span class="on-sale">' . esc_html__('Sale!', 'woocommerce') . '</span>';
		}
	}

	/**
	 * WC Sale Badge
	 *
	 * @since    3.1.0
	 * @version    2.0
	 */
	public function oxyninja_sale_badge() {
		global $product;
		if (is_a($product, 'WC_Product')) {
			if (!$product->is_on_sale()) {
				return;
			}
			$max_percentage = 0;
			if ($product->is_type('simple')) {
				$max_percentage =
					(($product->get_regular_price() - $product->get_sale_price()) / $product->get_regular_price()) *
					100;
			} elseif ($product->is_type('variable')) {
				foreach ($product->get_children() as $child_id) {
					$variation = wc_get_product($child_id);
					$price = $variation->get_regular_price();
					$sale = $variation->get_sale_price();
					if ($price != 0 && !empty($sale)) {
						$percentage = (($price - $sale) / $price) * 100;
					}
					if (isset($percentage)) {
						if ($percentage > $max_percentage) {
							$max_percentage = $percentage;
						}
					}
				}
			} elseif ($product->is_type('bundle')) {
				if ($product->get_regular_price() == 0) {
					$max_percentage =
						(($product->get_bundle_regular_price() - $product->get_bundle_price()) /
							$product->get_bundle_regular_price()) *
						100;
				} elseif ($product->get_regular_price() > 0) {
					$max_percentage =
						(($product->get_regular_price() - $product->get_sale_price()) / $product->get_regular_price()) *
						100;
				}
			}
			if ($max_percentage > 0 && $max_percentage < 99) {
				echo "<div class='wc-sale-badge'>-" . round($max_percentage) . '%</div>';
			} elseif ($max_percentage > 0 && $max_percentage >= 99.01) {
				echo "<div class='wc-sale-badge'>-99%</div>";
			}
		}
	}

	/**
	 * WooCore Cart Count
	 *
	 * @since    3.4.1
	 */

	public function woocore_cart_count($fragments) {
		global $woocommerce;

		if ($woocommerce->cart->get_cart_contents_count() > 0) {
			ob_start();
			echo '<span class="wc-cart-count">';
			echo WC()->cart->get_cart_contents_count();
			echo '</span>';
			$fragments['.wc-cart-count'] = ob_get_clean();
		} else {
			ob_start();
			echo '<span class="wc-cart-count empty">';
			echo WC()->cart->get_cart_contents_count();
			echo '</span>';
			$fragments['.wc-cart-count'] = ob_get_clean();
		}

		return $fragments;
	}

	// TODO : Check This

	/**
	 * WooCore MiniCart ShortCode
	 *
	 * @since    3.5.0
	 */
	public function oxyninja_minicart_shortcode($atts) {
		if (!class_exists('woocommerce')) {
			return __('WooCommerce is not active!', 'oxy-ninja');
		}

		global $woocommerce;
		if (is_null($woocommerce->cart)) {
			return false;
		}

		$_cart_qty = $woocommerce->cart ? $woocommerce->cart->cart_contents_count : 0;
		$_cart_total = $woocommerce->cart ? $woocommerce->cart->get_cart_subtotal() : 0;
		$_cart_qty1 = sprintf(_n('%d item', '%d items', $_cart_qty, 'oxy-ninja'), $_cart_qty);
		$has_items = !WC()->cart->is_empty();
		$items = sizeof(WC()->cart->get_cart());

		$atts = shortcode_atts(
			[
				'type' => 'mc',
				'heading' => 'true',
				'buttons' => 'both',
				'coupon' => 'show',
			],
			$atts,
			'oxyninja-cart'
		);

		ob_start();

		echo '<div class="';
		echo esc_attr($atts['type']) === 'mc' ? 'woocore-mini-cart-wrap' : 'woocore-panel-wrap';
		echo '">';

		// Your Cart - H4
		if (esc_attr($atts['heading']) === 'true'):
			echo '<h4 class="c-h4 c-margin-bottom-s">' . esc_html__('Your Cart', 'oxy-ninja') . '</h4>';
		endif;

		// First Row - Item Count + View Cart
		echo '<div class="woocore-cart-first-row c-margin-bottom-s">';
		echo '<span>' . sprintf(esc_html(_n('%d item', '%d items', $items, 'oxy-ninja')), $items) . '</span>';
		echo '<a class="c-text-dark" href="' .
			esc_url(wc_get_cart_url()) .
			'">' .
			esc_html__('View Cart', 'oxy-ninja') .
			'</a>';
		echo '</div>';
		?>

		<!-- List of Products // Start -->
		<ul class="woocore-cart_list c-margin-bottom-s woocore-scrollbar-inner">
			<?php if ($has_items): ?>
				<?php do_action('woocommerce_before_mini_cart_contents'); ?>
				<?php foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
    	$_product = apply_filters(
    		'woocommerce_cart_item_product',
    		$cart_item['data'],
    		$cart_item,
    		$cart_item_key
    	);
    	$product_id = apply_filters(
    		'woocommerce_cart_item_product_id',
    		$cart_item['product_id'],
    		$cart_item,
    		$cart_item_key
    	);

    	if (
    		$_product &&
    		$_product->exists() &&
    		$cart_item['quantity'] > 0 &&
    		apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key)
    	) {

    		$product_name = apply_filters(
    			'woocommerce_cart_item_name',
    			$_product->get_name(),
    			$cart_item,
    			$cart_item_key
    		);
    		$thumbnail = apply_filters(
    			'woocommerce_cart_item_thumbnail',
    			$_product->get_image('woocommerce_gallery_thumbnail'),
    			$cart_item,
    			$cart_item_key
    		);
    		$product_price = apply_filters(
    			'woocommerce_cart_item_price',
    			WC()->cart->get_product_price($_product),
    			$cart_item,
    			$cart_item_key
    		);
    		$product_permalink = apply_filters(
    			'woocommerce_cart_item_permalink',
    			$_product->is_visible() ? $_product->get_permalink($cart_item) : '',
    			$cart_item,
    			$cart_item_key
    		);
    		?>
			<li class="c-margin-bottom-s <?php echo esc_attr(
   	apply_filters('woocommerce_mini_cart_item_class', 'woocore-mini-cart-item', $cart_item, $cart_item_key)
   ); ?>">
				<div class="woocore-mini-cart-product-details">
					<a href="<?php echo esc_url($product_permalink); ?>" class="c-text-dark">
						<?php echo esc_html($product_name); ?>
					</a>
						<?php do_action('oxy-ninja_woocommerce_minicart_after_product_name', $_product); ?>
						<?php echo function_exists('wc_get_formatted_cart_item_data')
      	? wc_get_formatted_cart_item_data($cart_item)
      	: WC()->cart->get_item_data($cart_item); ?>
						<?php echo apply_filters(
      	'woocommerce_widget_cart_item_quantity',
      	'<span class="quantity">' .
      		sprintf('%s &times; %s', $cart_item['quantity'], $product_price) .
      		'</span>',
      	$cart_item,
      	$cart_item_key
      ); ?>
						<?php echo apply_filters(
      	'woocommerce_cart_item_remove_link',
      	sprintf(
      		'<a href="%s" class="woocore-remove-product" aria-label="%s" data-product_id="%s" data-cart_id="%s" data-product_sku="%s">×</a>',
      		esc_url(
      			function_exists('wc_get_cart_remove_url')
      				? wc_get_cart_remove_url($cart_item_key)
      				: WC()->cart->get_remove_url($cart_item_key)
      		),
      		esc_attr__('Remove this item', 'woocommerce'),
      		esc_attr($product_id),
      		esc_attr($cart_item_key),
      		esc_attr($_product->get_sku())
      	),
      	$cart_item_key
      ); ?>
				</div>
				<div class="woocore-mini-cart-product-image">
						<?php if (!$_product->is_visible()): ?>
							<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
					<?php else: ?>
					<a href="<?php echo esc_url($product_permalink); ?>">
						<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
					</a>
					<?php endif; ?>
				</div>
			</li>
						<?php
    	}
    } ?>

				<?php do_action('woocommerce_mini_cart_contents'); ?>

			<?php else: ?>

			<li class="woocore-mini-cart__empty-message">
				<?php esc_html_e('No products in the cart.', 'woocommerce'); ?>
			</li>

			<?php endif; ?>

		</ul>

		<!-- Subtotal + Total Row // Start -->
		<div class="woocore-mini-cart__total c-margin-bottom-s">
			<?php if (has_action('woocommerce_widget_shopping_cart_total')): ?>
				<?php do_action('woocommerce_widget_shopping_cart_total'); ?>
			<?php else: ?>
			<p class="c-text-dark"><?php esc_html_e('Total', 'oxy-ninja'); ?>:</p>
				<?php echo WC()->cart->get_cart_subtotal(); ?>
			<?php endif; ?>
		</div>

		<?php do_action('woocommerce_widget_shopping_cart_before_buttons'); ?>

		<!-- Cart + Checkout buttons -->
		<div class="woocore-mini-cart__buttons c-margin-bottom-s">
			<?php
   if (esc_attr($atts['buttons']) === 'both' || esc_attr($atts['buttons']) === 'cart') {
   	echo '<a href="' .
   		esc_url(wc_get_cart_url()) .
   		'" class="c-btn c-btn-alt c-btn-m c-margin-bottom-s c-transition">' .
   		esc_html__('View cart', 'woocommerce') .
   		'</a>';
   }
   if (esc_attr($atts['buttons']) === 'both' || esc_attr($atts['buttons']) === 'checkout') {
   	echo '<a href="' .
   		esc_url(wc_get_checkout_url()) .
   		'" class="c-btn c-btn-alt c-btn-m c-transition">' .
   		esc_html__('Checkout', 'woocommerce') .
   		'</a>';
   }
   ?>
		</div>

		<?php do_action('woocommerce_widget_shopping_cart_after_buttons'); ?>

		<!-- Subtotal + Total Row // End -->

		<?php $coupons_count = $woocommerce->cart->get_applied_coupons(); ?>

		<?php if (esc_attr($atts['coupon']) === 'show' && count($coupons_count) == 0) {
  	echo '<div class="woocore-mini-cart__coupon c-margin-bottom-s">';
  	echo '<input type="text" name="coupon" id="woocore-coupon"/>';
  	echo '<div class="c-btn-main c-btn-s c-transition" id="woocore-reedem-button">';
  	echo 'Reedem';
  	echo '</div>';
  	echo '</div>';
  } ?>

		<?php if (esc_attr($atts['coupon']) === 'show' && count($coupons_count) > 0) {
  	echo '<div class="woocore-mini-cart__coupons c-margin-bottom-s">';
  	foreach ($coupons_count as $single_coupon) {
  		echo '<div class="c-btn-alt c-btn-xs c-transition" id="woocore-reedem-button">';
  		echo $single_coupon;
  		echo '</div>';
  	}
  	echo '</div>';
  } ?>

		<?php
  do_action('woocommerce_after_mini_cart');
  wp_enqueue_script('woocore-ajax');
  echo '</div>';

  return ob_get_clean();
	}

	/**
	 * WooCore MiniCart Ajax - Remove
	 *
	 * @since    3.5.0
	 */
	public function oxyninja_minicart_ajax_remove() {
		ob_start();

		foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
			if ($cart_item['product_id'] == $_POST['product_id'] && $cart_item_key == $_POST['cart_item_key']) {
				WC()->cart->remove_cart_item($cart_item_key);
			}
		}

		WC()->cart->calculate_totals();
		WC()->cart->maybe_set_cart_cookies();

		// Product List Start
		$has_items = !WC()->cart->is_empty();
		if ($has_items) {
			foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
				$_product = apply_filters(
					'woocommerce_cart_item_product',
					$cart_item['data'],
					$cart_item,
					$cart_item_key
				);
				$product_id = apply_filters(
					'woocommerce_cart_item_product_id',
					$cart_item['product_id'],
					$cart_item,
					$cart_item_key
				);

				if (
					$_product &&
					$_product->exists() &&
					$cart_item['quantity'] > 0 &&
					apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key)
				) {

					$product_name = apply_filters(
						'woocommerce_cart_item_name',
						$_product->get_name(),
						$cart_item,
						$cart_item_key
					);
					$thumbnail = apply_filters(
						'woocommerce_cart_item_thumbnail',
						$_product->get_image('woocommerce_gallery_thumbnail'),
						$cart_item,
						$cart_item_key
					);
					$product_price = apply_filters(
						'woocommerce_cart_item_price',
						WC()->cart->get_product_price($_product),
						$cart_item,
						$cart_item_key
					);
					$product_permalink = apply_filters(
						'woocommerce_cart_item_permalink',
						$_product->is_visible() ? $_product->get_permalink($cart_item) : '',
						$cart_item,
						$cart_item_key
					);
					?>

				<li class="c-margin-bottom-s <?php echo esc_attr(
    	apply_filters('woocommerce_mini_cart_item_class', 'woocore-mini-cart-item', $cart_item, $cart_item_key)
    ); ?>">
				<div class="woocore-mini-cart-product-details">
				<a href="<?php echo esc_url($product_permalink); ?>" class="c-text-dark">
					<?php echo esc_html($product_name); ?>
				</a>
					<?php do_action('oxy-ninja_woocommerce_minicart_after_product_name', $_product); ?>
					<?php echo function_exists('wc_get_formatted_cart_item_data')
     	? wc_get_formatted_cart_item_data($cart_item)
     	: WC()->cart->get_item_data($cart_item); ?>
					<?php echo apply_filters(
     	'woocommerce_widget_cart_item_quantity',
     	'<span class="quantity">' .
     		sprintf('%s &times; %s', $cart_item['quantity'], $product_price) .
     		'</span>',
     	$cart_item,
     	$cart_item_key
     ); ?>
					<?php echo apply_filters(
     	'woocommerce_cart_item_remove_link',
     	sprintf(
     		'<a href="%s" class="woocore-remove-product" aria-label="%s" data-product_id="%s" data-cart_id="%s" data-product_sku="%s">×</a>',
     		esc_url(
     			function_exists('wc_get_cart_remove_url')
     				? wc_get_cart_remove_url($cart_item_key)
     				: WC()->cart->get_remove_url($cart_item_key)
     		),
     		esc_attr__('Remove this item', 'woocommerce'),
     		esc_attr($product_id),
     		esc_attr($cart_item_key),
     		esc_attr($_product->get_sku())
     	),
     	$cart_item_key
     ); ?>
				</div>
				<div class="woocore-mini-cart-product-image">
					<?php if (!$_product->is_visible()): ?>
						<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
				<?php else: ?>
				<a href="<?php echo esc_url($product_permalink); ?>">
					<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
				</a>
				<?php endif; ?>
				</div>
				</li>
					<?php
				}
			}
		} else {
			 ?>
			<li class="woocore-mini-cart__empty-message">
			<?php esc_html_e('No products in the cart.', 'woocommerce'); ?>
			</li>
			<?php
		}
		?>
		<?php
  do_action('woocommerce_mini_cart_contents');

  $mini_cart = ob_get_clean();

  $items = sizeof(WC()->cart->get_cart());
  $items_span =
  	'<span>' . sprintf(esc_html(_n('%d item', '%d items', $items, 'oxy-ninja')), $items) . '</span>';

  // Fragments and mini cart are returned
  $data = [
  	'fragments' => apply_filters('woocommerce_add_to_cart_fragments', [
  		'ul.woocore-cart_list' =>
  			'<ul class="woocore-cart_list c-margin-bottom-s woocore-scrollbar-inner">' . $mini_cart . '</ul>',
  	]),
  	'cart_hash' => apply_filters(
  		'woocommerce_add_to_cart_hash',
  		WC()->cart->get_cart_for_session() ? md5(json_encode(WC()->cart->get_cart_for_session())) : '',
  		WC()->cart->get_cart_for_session()
  	),
  	'subtotal' => WC()->cart->get_cart_total(),
  	'items' => $items_span,
  ];

  wp_send_json($data);

  wp_die();
	}

	/**
	 * WooCore MiniCart Ajax - Add
	 *
	 * @since    3.5.0
	 */
	public function oxyninja_minicart_ajax_add() {
		$product_id = apply_filters('woocommerce_add_to_cart_product_id', absint($_POST['product_id']));
		$quantity = empty($_POST['quantity']) ? 1 : wc_stock_amount($_POST['quantity']);
		$variation_id = absint($_POST['variation_id']);
		$passed_validation = apply_filters('woocommerce_add_to_cart_validation', true, $product_id, $quantity);
		$product_status = get_post_status($product_id);

		if (
			$passed_validation &&
			WC()->cart->add_to_cart($product_id, $quantity, $variation_id) &&
			'publish' === $product_status
		) {

			do_action('woocommerce_ajax_added_to_cart', $product_id);

			if ('yes' === get_option('woocommerce_cart_redirect_after_add')) {
				wc_add_to_cart_message([$product_id => $quantity], true);
			}

			// WC_AJAX :: get_refreshed_fragments();

			ob_start();

			foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
				if ($cart_item['product_id'] == $_POST['product_id'] && $cart_item_key == $_POST['cart_item_key']) {
					WC()->cart->remove_cart_item($cart_item_key);
				}
			}

			WC()->cart->calculate_totals();
			WC()->cart->maybe_set_cart_cookies();

			// Product List Start
			$has_items = !WC()->cart->is_empty();
			if ($has_items) {
				foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
					$_product = apply_filters(
						'woocommerce_cart_item_product',
						$cart_item['data'],
						$cart_item,
						$cart_item_key
					);
					$product_id = apply_filters(
						'woocommerce_cart_item_product_id',
						$cart_item['product_id'],
						$cart_item,
						$cart_item_key
					);

					if (
						$_product &&
						$_product->exists() &&
						$cart_item['quantity'] > 0 &&
						apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key)
					) {

						$product_name = apply_filters(
							'woocommerce_cart_item_name',
							$_product->get_name(),
							$cart_item,
							$cart_item_key
						);
						$thumbnail = apply_filters(
							'woocommerce_cart_item_thumbnail',
							$_product->get_image('woocommerce_gallery_thumbnail'),
							$cart_item,
							$cart_item_key
						);
						$product_price = apply_filters(
							'woocommerce_cart_item_price',
							WC()->cart->get_product_price($_product),
							$cart_item,
							$cart_item_key
						);
						$product_permalink = apply_filters(
							'woocommerce_cart_item_permalink',
							$_product->is_visible() ? $_product->get_permalink($cart_item) : '',
							$cart_item,
							$cart_item_key
						);
						?>

						<li class="c-margin-bottom-s <?php echo esc_attr(
      	apply_filters(
      		'woocommerce_mini_cart_item_class',
      		'woocore-mini-cart-item',
      		$cart_item,
      		$cart_item_key
      	)
      ); ?>">
						<div class="woocore-mini-cart-product-details">
						<a href="<?php echo esc_url($product_permalink); ?>" class="c-text-dark">
						<?php echo esc_html($product_name); ?>
						</a>
						<?php do_action('oxy-ninja_woocommerce_minicart_after_product_name', $_product); ?>
						<?php echo function_exists('wc_get_formatted_cart_item_data')
      	? wc_get_formatted_cart_item_data($cart_item)
      	: WC()->cart->get_item_data($cart_item); ?>
						<?php echo apply_filters(
      	'woocommerce_widget_cart_item_quantity',
      	'<span class="quantity">' .
      		sprintf('%s &times; %s', $cart_item['quantity'], $product_price) .
      		'</span>',
      	$cart_item,
      	$cart_item_key
      ); ?>
						<?php echo apply_filters(
      	'woocommerce_cart_item_remove_link',
      	sprintf(
      		'<a href="%s" class="woocore-remove-product" aria-label="%s" data-product_id="%s" data-cart_id="%s" data-product_sku="%s">×</a>',
      		esc_url(
      			function_exists('wc_get_cart_remove_url')
      				? wc_get_cart_remove_url($cart_item_key)
      				: WC()->cart->get_remove_url($cart_item_key)
      		),
      		esc_attr__('Remove this item', 'woocommerce'),
      		esc_attr($product_id),
      		esc_attr($cart_item_key),
      		esc_attr($_product->get_sku())
      	),
      	$cart_item_key
      ); ?>
					</div>
					<div class="woocore-mini-cart-product-image">
						<?php if (!$_product->is_visible()): ?>
							<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
						<?php else: ?>
						<a href="<?php echo esc_url($product_permalink); ?>">
							<?php echo str_replace(['http:', 'https:'], '', $thumbnail); ?>
						</a>
						<?php endif; ?>
					</div>
					</li>
						<?php
					}
				}
			} else {
				 ?>
				<li class="woocore-mini-cart__empty-message">
				<?php esc_html_e('No products in the cart.', 'woocommerce'); ?>
				</li>
				<?php
			}
			?>
			<?php
   do_action('woocommerce_mini_cart_contents');

   $mini_cart = ob_get_clean();

   $items = sizeof(WC()->cart->get_cart());
   $items_span =
   	'<span>' . sprintf(esc_html(_n('%d item', '%d items', $items, 'oxy-ninja')), $items) . '</span>';

   // Fragments and mini cart are returned
   $data = [
   	'fragments' => apply_filters('woocommerce_add_to_cart_fragments', [
   		'ul.woocore-cart_list' =>
   			'<ul class="woocore-cart_list c-margin-bottom-s woocore-scrollbar-inner">' . $mini_cart . '</ul>',
   	]),
   	'cart_hash' => apply_filters(
   		'woocommerce_add_to_cart_hash',
   		WC()->cart->get_cart_for_session() ? md5(json_encode(WC()->cart->get_cart_for_session())) : '',
   		WC()->cart->get_cart_for_session()
   	),
   	'subtotal' => WC()->cart->get_cart_total(),
   	'items' => $items_span,
   ];

   wp_send_json($data);

		} else {
			$data = [
				'error' => true,
				'product_url' => apply_filters(
					'woocommerce_cart_redirect_after_error',
					get_permalink($product_id),
					$product_id
				),
			];

			echo wp_send_json($data);
		}

		wp_die();
	}

	/**
	 * WooCore MiniCart Ajax - Remove
	 *
	 * @since    3.5.0
	 */
	public function oxyninja_quick_view() {
		$product_id = absint($_POST['product_id']);
		if (!$product_id) {
			return false;
		}

		$product = wc_get_product($product_id);

		// ob_start();

		// foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
		// 	if($cart_item['product_id'] == $_POST['product_id'] && $cart_item_key == $_POST['cart_item_key'] ) {
		// 		WC()->cart->remove_cart_item($cart_item_key);
		// 	}
		// }

		// $mini_cart = ob_get_clean();

		$data = [
			'name' => $product->get_name(),
			'price' => $product->get_regular_price(),
			'price_html' => wc_price($product->get_regular_price()),
			'sale' => wc_price($product->get_sale_price()),
			'sale_html' => $product->get_sale_price(),
			'type' => $product->get_type(),
			'short_description' => $product->get_short_description(),
			'stock' => $product->get_stock_status(),
			'attributes' => $product->get_attributes(),
			'image_id' => $product->get_image_id(),
			'image' => $product->get_image(),
			'image_gallery' => $product->get_gallery_image_ids(),
		];

		wp_send_json($data);

		wp_die();
	}

	/**
	 * WooCore Cart Ajax - Coupon
	 *
	 * @since    3.5.0
	 */
	public function oxyninja_woocore_coupon() {
		$coupon_id = $_POST['coupone_code'];
		if (!$coupon_id) {
			return false;
		}

		// $product = wc_get_product( $coupon_id );

		// ob_start();

		// foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
		// 	if($cart_item['coupon_id'] == $_POST['coupon_id'] && $cart_item_key == $_POST['cart_item_key'] ) {
		// 		WC()->cart->remove_cart_item($cart_item_key);
		// 	}
		// }

		// $mini_cart = ob_get_clean();

		$coupon = !in_array($coupon_id, WC()->cart->get_applied_coupons());

		if (!in_array($coupon_id, WC()->cart->get_applied_coupons())) {
			$coupon = WC()->cart->apply_coupon($coupon_id);
		}

		ob_start();
		wc_print_notices();
		$messages = ob_get_clean();

		$data = [
			'coupon' => $coupon,
			'message' => isset($messages) ? $messages : '',
		];

		wp_send_json($data);

		wp_die();
	}
}
